/*!
 * PMD 85 ColorAce picture editor
 * onReady initialization and entry point
 *
 * Copyright (c) 2012 Martin Borik
 */

var editor = null, mousedown = 0, notmoved = false,
	lastPixelX = -1, lastPixelY = -1;

//- resizing handler ----------------------------------------------------------
var resizeWrapper = function() {
	var wrapW = $(window).width(), wrapH = $(window).height();
	$('#wrapper').css({ width:  wrapW + 'px', height: wrapH + 'px' });
	$('#leftPanel').css({ height: wrapH + 'px' });
	$("#mainPanel").css({ height: wrapH + 'px' });
	editor.setDimensions($("#mainPanel").width(), wrapH);
};

//-----------------------------------------------------------------------------
$(document).ready(function() {
	editor = new ColorAceEditor({
		canvas : $("#myCanvas")[0],
		grid   : true,
		undo   : 20
	});

	resizeWrapper();
	$(window).resize(resizeWrapper);
	$(document).bind("contextmenu", function(e) {
		e.preventDefault();
		return false
	});

	$("#mainPanel").mousewheel(function(e, delta) {
		editor.scroller.doMouseZoom(delta, e.timeStamp, e.pageX, e.pageY);
	});

	$("#mainPanel").mousedown(function(e) {
		if (!e) var e = window.event;
		if ((e.which && e.which > 1) || (e.button && e.button > 0)) {
			editor.scroller.doTouchStart([{
				pageX: e.pageX,
				pageY: e.pageY
			}], e.timeStamp);
			mousedown = 2;
		}
		else {
			var coords = editor.translateCoords(e.pageX, e.pageY);
			lastPixelX = coords.x;
			lastPixelY = coords.y;
			mousedown = 1;
		}

		notmoved = true;
	});

	$(document).mousemove(function(e) {
		if (mousedown == 0)
			return;
		else if (mousedown == 2) {
			editor.scroller.doTouchMove([{
				pageX: e.pageX,
				pageY: e.pageY
			}], e.timeStamp);
		}
		else {
			var coords = editor.translateCoords(e.pageX, e.pageY);
			if (lastPixelX != coords.x || lastPixelY != coords.y)
				editor.draw.line(lastPixelX, lastPixelY, coords.x, coords.y, notmoved);

			lastPixelX = coords.x;
			lastPixelY = coords.y;
		}

		notmoved = false;
	});

	$(document).mouseup(function(e) {
		if (!mousedown)
			return;

		if (!e) var e = window.event;
		if ((e.which && e.which > 1) || (e.button && e.button > 0))
			editor.scroller.doTouchEnd(e.timeStamp);
		else {
			var coords = editor.translateCoords(e.pageX, e.pageY);
			if (notmoved)
				editor.draw.dot(coords.x, coords.y);
			else if (lastPixelX != coords.x || lastPixelY != coords.y)
				editor.draw.line(lastPixelX, lastPixelY, coords.x, coords.y, true);
		}

		lastPixelX = -1; lastPixelY = -1;
		notmoved = false;
		mousedown = 0;
	});

	$('#clear-button').button({
		icons: { primary: "ui-icon-new" },
		text: false
	});

	$('#upload-button').button({
		icons: { primary: "ui-icon-load" }
	}).click(function() {
		$('#upload-file:file').click();
		return false;
	});

	$('*[id^=upload-]').hover(
		function() { $("#upload-button").addClass("ui-state-hover"); },
		function() { $("#upload-button").removeClass("ui-state-hover"); }
	);

	$('#upload-file:file').change(function() { $.ajax({
		url: 'file.php',
		type: 'POST',
		success: function(result) {
			if (result.success) $.ajax({
				url: 'file.php',
				data: { q: result.name },
				success: function(d) {
					editor.pixel.readPMD85vram(d);
					editor.scroller.zoomTo(editor.zoomFactor);
				},
				dataType: 'dataview',
				cache: false,
				contentType: false
			});
			else alert(result.msg);
		},
		data: new FormData(this.form),
		dataType: 'json',
		cache: false,
		contentType: false,
		processData: false
	})});

	$('#save-button').button({
		icons: { primary: "ui-icon-save" }
	}).click(function() {
		var data = $('#save-data')[0], form = $('#save-form')[0];
		data.value = editor.pixel.savePMD85vram();
		form.action = "save.php";
		form.method = "POST";
		form.submit();
		data.value = '';
		return false;
	});

	$('#tools').buttonset();
	$('#tool0').button({
		icons: { primary: "ui-icon-select" },
		text: false
	});
	$('#tool1').button({
		icons: { primary: "ui-icon-select-grid" },
		text: false
	});
	$('#tool2').button({
		icons: { primary: "ui-icon-pencil" },
		text: false
	});
	$('#tool3').button({
		icons: { primary: "ui-icon-brush" },
		text: false
	});
	$('#tool4').button({
		icons: { primary: "ui-icon-fill" },
		text: false
	});
	$('#tool5').button({
		icons: { primary: "ui-icon-lines" },
		text: false
	});
	$('#tool6').button({
		icons: { primary: "ui-icon-ellipse" },
		text: false
	});
	$('#tool7').button({
		icons: { primary: "ui-icon-rectangle" },
		text: false
	});

	$('#colors').buttonset();
	$('#drawing-mode').buttonset();

	$("#colors > input:radio").click(function() {
		editor.editColor = parseInt(this.value);
		return false;
	});
	$("#drawing-mode > input:radio").click(function() {
		editor.editMode = parseInt(this.value);
		return false;
	});
});
